"""Package to detect spindles, ripples, slow waves.
"""
from .spindle import DetectSpindle, merge_close
from .ripple import DetectRipple
from .slowwave import DetectSlowWave
